# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdCol(Component):
    """An AntdCol component.
列组件AntdCol

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- span (number; optional):
    列所占宽度份数.

- offset (number; default 0):
    列左侧间隔宽度份数 默认值：`0`.

- order (number; default 0):
    列顺序 默认值：`0`.

- pull (number; default 0):
    列向左移动宽度份数 默认值：`0`.

- push (number; default 0):
    列向右移动宽度份数 默认值：`0`.

- flex (string | number; optional):
    同css中的flex.

- xs (dict; optional):
    配置列在页面宽度小于567px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `xs` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- sm (dict; optional):
    配置列在页面宽度大于等于567px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `sm` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- md (dict; optional):
    配置列在页面宽度大于等于768px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `md` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- lg (dict; optional):
    配置列在页面宽度大于等于992px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `lg` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- xl (dict; optional):
    配置列在页面宽度大于等于1200px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `xl` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- xxl (dict; optional):
    配置列在页面宽度大于等于1600px时的布局参数，传入数值型时代表span参数，传入字典时分别设置各布局参数.

    `xxl` is a number | dict with keys:

    - span (number; optional):
        同span参数.

    - offset (number; optional):
        同offset参数.

    - order (number; optional):
        同order参数.

    - pull (number; optional):
        同pull参数.

    - push (number; optional):
        同push参数.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCol'
    Xs = TypedDict(
        "Xs",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "order": NotRequired[NumberType],
            "pull": NotRequired[NumberType],
            "push": NotRequired[NumberType]
        }
    )

    Sm = TypedDict(
        "Sm",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "order": NotRequired[NumberType],
            "pull": NotRequired[NumberType],
            "push": NotRequired[NumberType]
        }
    )

    Md = TypedDict(
        "Md",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "order": NotRequired[NumberType],
            "pull": NotRequired[NumberType],
            "push": NotRequired[NumberType]
        }
    )

    Lg = TypedDict(
        "Lg",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "order": NotRequired[NumberType],
            "pull": NotRequired[NumberType],
            "push": NotRequired[NumberType]
        }
    )

    Xl = TypedDict(
        "Xl",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "order": NotRequired[NumberType],
            "pull": NotRequired[NumberType],
            "push": NotRequired[NumberType]
        }
    )

    Xxl = TypedDict(
        "Xxl",
            {
            "span": NotRequired[NumberType],
            "offset": NotRequired[NumberType],
            "order": NotRequired[NumberType],
            "pull": NotRequired[NumberType],
            "push": NotRequired[NumberType]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        span: typing.Optional[NumberType] = None,
        offset: typing.Optional[NumberType] = None,
        order: typing.Optional[NumberType] = None,
        pull: typing.Optional[NumberType] = None,
        push: typing.Optional[NumberType] = None,
        flex: typing.Optional[typing.Union[str, NumberType]] = None,
        xs: typing.Optional[typing.Union[NumberType, "Xs"]] = None,
        sm: typing.Optional[typing.Union[NumberType, "Sm"]] = None,
        md: typing.Optional[typing.Union[NumberType, "Md"]] = None,
        lg: typing.Optional[typing.Union[NumberType, "Lg"]] = None,
        xl: typing.Optional[typing.Union[NumberType, "Xl"]] = None,
        xxl: typing.Optional[typing.Union[NumberType, "Xxl"]] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'span', 'offset', 'order', 'pull', 'push', 'flex', 'xs', 'sm', 'md', 'lg', 'xl', 'xxl', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'span', 'offset', 'order', 'pull', 'push', 'flex', 'xs', 'sm', 'md', 'lg', 'xl', 'xxl', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCol, self).__init__(children=children, **args)

setattr(AntdCol, "__init__", _explicitize_args(AntdCol.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdAccordion(Component):
    """An AntdAccordion component.
手风琴组件AntdAccordion

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- styles (dict; optional):
    细分控制子元素css样式.

    `styles` is a dict with keys:

    - header (dict; optional):
        头部元素css样式.

    - body (dict; optional):
        内容元素css样式.

- classNames (dict; optional):
    细分控制子元素css类名.

    `classNames` is a dict with keys:

    - header (string; optional):
        头部元素css类名.

    - body (string; optional):
        内容元素css类名.

- items (list of dicts; optional):
    定义手风琴子项.

    `items` is a list of dicts with keys:

    - children (a list of or a singular dash component, string or number; optional):
        当前子项内部元素.

    - className (string | dict; optional):
        当前子项css类名，支持[动态css](/advanced-classname).

    - style (dict; optional):
        当前子项css样式.

    - key (string | number; required):
        必填，当前子项唯一key值.

    - collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
        当前子项折叠触发方式，可选项有`'header'`、`'disabled'`、`'icon'`.

    - title (a list of or a singular dash component, string or number; optional):
        当前子项标题元素.

    - extra (a list of or a singular dash component, string or number; optional):
        当前子项右上角额外元素.

    - showArrow (boolean; optional):
        是否展示当前手风琴项的箭头图标 默认值：`True`.

    - forceRender (boolean; optional):
        是否强制渲染内部元素 默认值：`False`.

- accordion (boolean; default True):
    是否开启手风琴模式 默认值：`True`.

- activeKey (string | list of strings | number | list of numbers; optional):
    监听或设置当前处于展开状态的手风琴项key值.

- defaultActiveKey (string | list of strings | number | list of numbers; optional):
    设置初始化处于展开状态的手风琴项key值.

- bordered (boolean; default True):
    是否渲染边框 默认值：`True`.

- size (a value equal to: 'large', 'middle', 'small'; default 'middle'):
    组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

- collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
    设置所有子项折叠触发方式，可选项有`'header'`、`'disabled'`、`'icon'`.

- expandIconPosition (a value equal to: 'left', 'right'; default 'left'):
    设置折叠图标位置，可选项有`'left'`、`'right'`.

- ghost (boolean; default False):
    是否开启透明无边框模式 默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = ['items[].children', 'items[].title', 'items[].extra']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAccordion'
    Styles = TypedDict(
        "Styles",
            {
            "header": NotRequired[dict],
            "body": NotRequired[dict]
        }
    )

    ClassNames = TypedDict(
        "ClassNames",
            {
            "header": NotRequired[str],
            "body": NotRequired[str]
        }
    )

    Items = TypedDict(
        "Items",
            {
            "children": NotRequired[ComponentType],
            "className": NotRequired[typing.Union[str, dict]],
            "style": NotRequired[dict],
            "key": typing.Union[str, NumberType],
            "collapsible": NotRequired[Literal["header", "disabled", "icon"]],
            "title": NotRequired[ComponentType],
            "extra": NotRequired[ComponentType],
            "showArrow": NotRequired[bool],
            "forceRender": NotRequired[bool]
        }
    )


    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional["Styles"] = None,
        classNames: typing.Optional["ClassNames"] = None,
        items: typing.Optional[typing.Sequence["Items"]] = None,
        accordion: typing.Optional[bool] = None,
        activeKey: typing.Optional[typing.Union[str, typing.Sequence[str], NumberType, typing.Sequence[NumberType]]] = None,
        defaultActiveKey: typing.Optional[typing.Union[str, typing.Sequence[str], NumberType, typing.Sequence[NumberType]]] = None,
        bordered: typing.Optional[bool] = None,
        size: typing.Optional[Literal["large", "middle", "small"]] = None,
        collapsible: typing.Optional[Literal["header", "disabled", "icon"]] = None,
        expandIconPosition: typing.Optional[Literal["left", "right"]] = None,
        ghost: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'style', 'className', 'styles', 'classNames', 'items', 'accordion', 'activeKey', 'defaultActiveKey', 'bordered', 'size', 'collapsible', 'expandIconPosition', 'ghost', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'style', 'className', 'styles', 'classNames', 'items', 'accordion', 'activeKey', 'defaultActiveKey', 'bordered', 'size', 'collapsible', 'expandIconPosition', 'ghost', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAccordion, self).__init__(**args)

setattr(AntdAccordion, "__init__", _explicitize_args(AntdAccordion.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401
from typing_extensions import TypedDict, NotRequired, Literal # noqa: F401
from dash.development.base_component import Component, _explicitize_args

ComponentType = typing.Union[
    str,
    int,
    float,
    Component,
    None,
    typing.Sequence[typing.Union[str, int, float, Component, None]],
]

NumberType = typing.Union[
    typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex
]


class AntdSkeleton(Component):
    """An AntdSkeleton component.
骨架屏组件AntdSkeleton

Keyword arguments:

- id (string; optional):
    组件唯一id.

- key (string; optional):
    对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

- children (a list of or a singular dash component, string or number; optional):
    组件型，内嵌元素.

- className (string | dict; optional):
    当前组件css类名，支持[动态css](/advanced-classname).

- loading (boolean; default False):
    是否处于加载中状态.

- active (boolean; default False):
    是否显示动画 默认值：`False`.

- delay (number; default 0):
    加载动画渲染延时，单位：毫秒 默认值：`0`.

- avatar (dict; default False):
    配置头像占位图相关参数，设置为`False`时不显示 默认值：`True`.

    `avatar` is a boolean | dict with keys:

    - active (boolean; optional):
        头像占位图是否显示动画 默认值：`False`.

    - shape (a value equal to: 'circle', 'square'; optional):
        头像占位图形状，可选项有`'circle'`、`'square'`.

    - size (number | a value equal to: 'large', 'small', 'default'; optional):
        头像占位图尺寸，传入数值型表示像素尺寸，也可传入预设的尺寸规格，可选项有`'large'`、`'small'`、`'default'`
        默认值：`'default'`.

- paragraph (dict; default True):
    配置段落占位图相关参数，设置为`False`时不显示 默认值：`True`.

    `paragraph` is a boolean | dict with keys:

    - rows (number; optional):
        段落占位图行数.

    - width (number | string | list of number | strings; optional):
        段落占位图宽度，当传入*int*或*string*型时，用于设置段落占位图最后一行的宽度，当传入*list*型时，用于逐行设置宽度.

- title (dict; default True):
    是否显示标题占位图 默认值：`True`.

    `title` is a boolean | dict with keys:

    - width (number | string; optional):
        标题占位图宽度.

- round (boolean; default False):
    段落、标题占位图是否渲染圆角 默认值：`False`.

- debug (boolean; default False):
    是否开启debug模式，开启后，每次动画加载都会在开发者工具的控制台打印相关`prop`信息 默认值：`False`.

- listenPropsMode (a value equal to: 'default', 'exclude', 'include'; default 'default'):
    监听模式，可选项有`'default'`、`'exclude'`、`'include'` 默认值：`'default'`.

- excludeProps (list of strings; optional):
    `listenPropsMode='exclude'`时，设置需要排除监听的回调目标列表，格式如`['组件id1.组件属性1',
    '组件id2.组件属性2', ...]`.

- includeProps (list of strings; optional):
    `listenPropsMode='include'`时，设置需要包含监听的回调目标列表，格式如`['组件id1.组件属性1',
    '组件id2.组件属性2', ...]`.

- manual (boolean; default False):
    是否开启手动控制模式，开启后是否处于加载状态将由`loading`参数控制，与内部元素参与的回调状态无关 默认值：`False`.

- data-* (string; optional):
    `data-*`格式属性通配.

- aria-* (string; optional):
    `aria-*`格式属性通配."""
    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSkeleton'
    Avatar = TypedDict(
        "Avatar",
            {
            "active": NotRequired[bool],
            "shape": NotRequired[Literal["circle", "square"]],
            "size": NotRequired[typing.Union[NumberType, Literal["large", "small", "default"]]]
        }
    )

    Paragraph = TypedDict(
        "Paragraph",
            {
            "rows": NotRequired[NumberType],
            "width": NotRequired[typing.Union[NumberType, str, typing.Sequence[typing.Union[NumberType, str]]]]
        }
    )

    Title = TypedDict(
        "Title",
            {
            "width": NotRequired[typing.Union[NumberType, str]]
        }
    )


    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        loading: typing.Optional[bool] = None,
        active: typing.Optional[bool] = None,
        delay: typing.Optional[NumberType] = None,
        avatar: typing.Optional[typing.Union[bool, "Avatar"]] = None,
        paragraph: typing.Optional[typing.Union[bool, "Paragraph"]] = None,
        title: typing.Optional[typing.Union[bool, "Title"]] = None,
        round: typing.Optional[bool] = None,
        debug: typing.Optional[bool] = None,
        listenPropsMode: typing.Optional[Literal["default", "exclude", "include"]] = None,
        excludeProps: typing.Optional[typing.Sequence[str]] = None,
        includeProps: typing.Optional[typing.Sequence[str]] = None,
        manual: typing.Optional[bool] = None,
        **kwargs
    ):
        self._prop_names = ['id', 'key', 'children', 'style', 'className', 'loading', 'active', 'delay', 'avatar', 'paragraph', 'title', 'round', 'debug', 'listenPropsMode', 'excludeProps', 'includeProps', 'manual', 'data-*', 'aria-*']
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['id', 'key', 'children', 'style', 'className', 'loading', 'active', 'delay', 'avatar', 'paragraph', 'title', 'round', 'debug', 'listenPropsMode', 'excludeProps', 'includeProps', 'manual', 'data-*', 'aria-*']
        self.available_wildcard_properties =            ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSkeleton, self).__init__(children=children, **args)

setattr(AntdSkeleton, "__init__", _explicitize_args(AntdSkeleton.__init__))
